%define anolis_release 2

%global common_description %{expand:
Jedi is a static analysis tool for Python that can be used in IDEs/editors. Its
historic focus is autocompletion, but does static analysis for now as well.
Jedi is fast and is very well tested. It understands Python on a deeper level
than all other static analysis frameworks for Python.}

%bcond_with tests

# jedi bundles 2 other projects
# when using the git tarball, the projects need to be pulled separately
# when using tarballs from PyPI, those are included
%global django_stubs_commit fd057010f6cbf176f57d1099e82be46d39b99cb9
%global typeshed_commit     ae9d4f4b21bb5e1239816c301da7b1ea904b44c3

Name:           python-jedi
Version:        0.18.2
Release:        %{anolis_release}%{?dist}
Summary:        An auto completion tool for Python that can be used for text editors

# jedi is MIT
# django-stubs is MIT
# typeshed is MIT ASL 2.0
License:        MIT and ASL 2.0

URL:            https://jedi.readthedocs.org
Source0:        https://github.com/davidhalter/jedi/archive/v%{version}/jedi-%{version}.tar.gz
Source1:        https://github.com/davidhalter/django-stubs/archive/%{django_stubs_commit}/django-stubs-%{django_stubs_commit}.tar.gz
Source2:        https://github.com/davidhalter/typeshed/archive/%{typeshed_commit}/typeshed-%{typeshed_commit}.tar.gz
BuildArch:      noarch

%description %{common_description}

%package -n python3-jedi
Summary:        %{summary}
BuildRequires:  python3-devel
Provides:       bundled(python3dist(django-stubs)) = %{django_stubs_commit}
Provides:       bundled(typeshed) = %{typeshed_commit}

%description -n python3-jedi %{common_description}


%prep
%autosetup -n jedi-%{version} -p 1

# git submodules
pushd jedi/third_party
rmdir django-stubs typeshed
tar xf %{SOURCE1} && mv django-stubs-%{django_stubs_commit} django-stubs
tar xf %{SOURCE2} && mv typeshed-%{typeshed_commit} typeshed
popd
cp -p jedi/third_party/django-stubs/LICENSE.txt LICENSE-django-stubs.txt
cp -p jedi/third_party/typeshed/LICENSE LICENSE-typeshed.txt

# relax upper limits on test dependencies
sed -e 's/pytest<7.0.0/pytest/' \
    -e 's/Django<3.1/Django/' \
    -i setup.py


%generate_buildrequires
%pyproject_buildrequires %{?with_tests:-x testing}


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files jedi


%check
%if %{with tests}
# TODO investigate failing / skipped tests
# venv_and_pths: %%pytest manipulates the sys.path
# Around 15 tests have some troubles with Python 3.11
# Reported upstream: https://github.com/davidhalter/jedi/issues/1858
%pytest --ignore test/test_integration.py -k \
    "not venv_and_pths and \
     not test_import and \
     not test_find_system_environments and \
     not test_string_annotation and \
     not test_find_module_not_package and \
     not test_infer_and_goto and \
     not test_goto_stubs"
%else
%pyproject_check_import
%endif


%files -n python3-jedi -f %{pyproject_files}


%changelog
* Fri Mar 15 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 0.18.2-2
- Rebuild with python3.11

* Wed May 03 2023 Funda Wang <fundawang@yeah.net> - 0.18.2-1
- Import package for anolis 23
